Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(465)

Unified Diff: mojo/system/channel.h

Issue 223783006: Mojo: Make Channel take a RawChannel rather than creating it. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: spurious space Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mojo/embedder/embedder.cc ('k') | mojo/system/channel.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/system/channel.h
diff --git a/mojo/system/channel.h b/mojo/system/channel.h
index 4af6daa8a0acca9a613558d9c17b3a397e766db5..fe876beaf364d5a3e2e27f7840ef4495aa9e4da6 100644
--- a/mojo/system/channel.h
+++ b/mojo/system/channel.h
@@ -59,11 +59,9 @@ class MOJO_SYSTEM_IMPL_EXPORT Channel
// This must be called on the creation thread before any other methods are
// called, and before references to this object are given to any other
- // threads. |handle| should be a handle to a (platform-appropriate)
- // bidirectional communication channel (e.g., a socket on POSIX, a named pipe
- // on Windows). Returns true on success. On failure, no other methods should
- // be called (including |Shutdown()|).
- bool Init(embedder::ScopedPlatformHandle handle);
+ // threads. |raw_channel| should be uninitialized. Returns true on success. On
+ // failure, no other methods should be called (including |Shutdown()|).
+ bool Init(scoped_ptr<RawChannel> raw_channel);
// This must be called on the creation thread before destruction (which can
// happen on any thread).
« no previous file with comments | « mojo/embedder/embedder.cc ('k') | mojo/system/channel.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698